function y = ASMFilter(Pars, x, dt, rep)
% y = ASMFilter(Pars, x, dt, rep)
%
% Apply ASM filter to time-series x.
%
% % Input:
%   Pars	Structure containing ASM instrument filter
%		parameters for 50 Hz sampling rate
%	Delay	    Group delay of filter
%	Coeff	    Filter coefficients
%   x		Data series - no gaps!
%   dt		Time-step - used for initial values
%   rep		Number of repetitions of filter. Optional.
%
% Output
%   y		Filtered values
%
%
% $Revision: 2.1 $

% $Id: ASMFilter.m,v 2.1 2007/02/15 13:31:32 lastec Exp lastec $

% Check rep input argument
if((nargin < 4) || (rep < 1))
  rep = 1;
end%if

while(rep > 0)
  % Estimate initial values - eq (5.2-140) of SW-RS-DSC-SY-0002
  dx0 = x(2) - x(1);
  x0 = x(1) - dx0 * [1 2];
  y0 = x(1) - dx0 * (Pars.Delay/dt + [0 1]);

  % Apply filter
  y = filter(Pars.Coeff(1,:), Pars.Coeff(2,:), x, ...
             filtic(Pars.Coeff(1,:), Pars.Coeff(2,:), y0, x0));

  % Update rep, prepare repetition if needed
  rep = rep - 1;
  if(rep > 0)
    x = y;
  end%if
end%while(rep > 0)

return;
