%% Plot results of VFM In-flight calibration tests
% $Id: doplot.m,v 1.1 2007/12/14 11:10:31 lastec Exp $

if(exist('CalManeuver', 'var') == 0)
  CalManeuver = 0;
end%if

% Load Results (array of structures)
if(CalManeuver)
  load results_cal_maneuver
  suffix = 'CalManeuver';
else
  load results
  suffix = '';
end%if

% Scaling of parameters for visual comparison
us = 50000 / 3600 * pi / 180;	% arc-seconds scaled to 1 nT
                                % in 50000 nT ambient field
par_scale = [1 1 1 50000 50000 50000 us us us];

% Look-up tables for converting batch-length respectively
% sample-frequency to array indices: b2i and f2i.
b2i = zeros(1,24);
b2i([3 6 9 12 18 24]) = 1:6;
f2i = zeros(1,16);
f2i([1 2 4 8 16]) = 1:5;

% Store Results in more convenient 4-D arrays with indices like:
% diff(model, parameter, batch-length-index, sample-frequency-index)
for i=1:numel(Results)
  % Assign short names of frequently used vars
  m = Results(i).model_no;
  bi = b2i(Results(i).batch);
  fi = f2i(Results(i).samp_freq);
  c = Results(i).est_pars.cov;
  
  % Fill arrays
  diff(m, :, bi, fi) = ...
      ([Results(i).est_pars.bias ...
        Results(i).est_pars.scale ...
        Results(i).est_pars.n_orth] - Results(i).model) .* ...
      par_scale;
  
  err(m, :, bi, fi) = sqrt(diag(c))' .* par_scale;
  
  ss = sqrt(par_scale(4));
  cov(m, :, bi, fi) = ...
      [max(max(tril(c(1:3,1:3),-1))) ...	% Inter-bias
       max(max(tril(c(4:6,4:6),-1))) * ss ...	% Inter-scale
       max(max(tril(c(7:9,7:9),-1))) ...	% Inter-non_orth
       max(max(c(1:3,4:6))) * ss ...		% Bias-scale
       max(max(c(1:3,7:9))) ...			% Bias-non_orth
       max(max(c(4:6,7:9))) * ss];		% Scale-non_orth
end%for i

% Make abscissa
x = repmat((1:size(diff,3))', 1, size(diff,4)) + ...
    repmat(0:0.1:(size(diff,4)-1)/10, size(diff,3), 1);

%------------------------------------------------------------
% Plots:
%------------------------------------------------------------
% Show that all models yield almost identical deviations
subplot(1,1,1)
for p=1:size(diff,2)
  plot(reshape(x', 1, []), ...
       p*5e-3 + detrend(reshape(diff(:,p,:,:), size(diff,1), []), ...
                       'constant')', ...
       'x');
  hold on
end%for p
errorbar(1.7, 7.5e-3, 2.5e-3, '-k')
text(1.75, 7.5e-3, '5 pT')
hold off
axis([0.8 6.6 3e-3 0.046])
legend('Model 1', 'Model 2', 'Model 3', 'Model 4', ...
       'Model 5', 'Model 6', 'Model 7', ...
       'Location', 'NorthOutside', ...
       'Orientation', 'Horizontal')
xlabel 'batch length [hours]'
ylabel 'Deviations Between Models'
set(gca, ...
    'XTick', 1:size(diff,3), ...
    'XTickLabel', num2str(find(b2i' ~= 0)), ...
    'YTick', (1:size(diff,2)) * 5e-3, ...
    'YTickLabel', 'b1|b2|b3|s1|s2|s3|u1|u2|u3', ...
    'YGrid', 'on')

set(gcf, 'PaperOrientation', 'Portrait', 'PaperType', 'A4', ...
         'PaperUnits', 'points', ...
         'PaperPosition', [0 0 959.7 959.7]); % Yields 1600x1600 pixels ...
print('-dpng', ['ModelDifferences' suffix '.png']);

% Now plot deviations
%for m=1:size(diff,1)
%  subplot(4,2,m)
m = 1;
  for p=1:size(diff,2)
    errorbar(x, ...
             2*squeeze(diff(m, p, :, :)) + 2*p + floor((p-1)/3), ...
             2*squeeze(err(m, p, :, :)), ...
             'x')
    if(p == 1)
      hold on
    end%if
  end%for p
  errorbar(1.7, 3, 1, '-k')
  text(1.75, 3, '1 nT')
  axis tight
  baselines = [2 4 6   9 11 13   16 18 20];
  plot(get(gca, 'XLim'), ...
       reshape(repmat(baselines, 4, 1) + ...
               repmat([-0.2 -0.2 0.2 0.2]', size(baselines)), ...
               2, []), ...
       '--g')
  hold off  
  xlabel 'batch length [hours]'
  ylabel 'deviations'
  %title(sprintf('Model %d', m));
  set(gca, ...
      'XTick', 1:size(diff,3), ...
      'XTickLabel', num2str(find(b2i' ~= 0)), ...
      'YTick', baselines, ...
      'YTickLabel', 'b1|b2|b3|s1|s2|s3|u1|u2|u3', ...
      'YGrid', 'on')
%end%for m
%xlabel 'batch length [hours]'

%subplot(4,2,8)
%plot([0 1], repmat([0 1], size(diff,4), 1), 'x-')
legend('1 second', ...
       '2 second', ...
       '4 second', ...
       '8 second', ...
       '16 second  (sample rate)', ...
       'Location', 'NorthOutside', ...
       'Orientation', 'Horizontal');

axis([0.8 6.6 1.5 22])
print('-dpng', ['Deviations' suffix '.png']);

% If the original data are available - plot them as well
if(exist('B', 'var') & exist('t', 'var'))
  subplot(2,1,1)
  plot(t/3600, [B/1000 sqrt(sum(B .^ 2, 2))/1000]);
  axis tight
  set(gca, 'YLim', get(gca, 'YLim') .* [1 1.25]);
  grid on
  xlabel 'time of day [hour]'
  ylabel 'VFM, F_{VFM} [\mu{}T]'
  title 'Basic Data Set'
  legend('VFM_x', 'VFM_y', 'VFM_z', 'F_{VFM}', ...
         'Location', 'North', ...
         'Orientation', 'Horisontal')

  subplot(2,1,2)
  i = find((t >= 0) & (t <= 5));
  B0 = 1000 * round(B(i(1),:) / 1000);
  F = sqrt(sum(B(i,:) .^ 2, 2));
  F0 = 5 * round(mean(F)/5);
  axh = plotyy(t(i), B(i,:) - repmat(B0, numel(i), 1), ...
               t(i), F - F0);
  axis tight
  set(get(axh(1),'Ylabel'), 'String', '\delta{}VFM [nT]');
  set(get(axh(2),'Ylabel'), 'String', '\delta{}F_{VFM} [nT]');
  set(get(axh(2),'Xlabel'), 'String', 'time of day [second]');
  set(axh(2), 'XLim', get(axh(1), 'XLim'), ...		% Hack(?)
              'YLim', get(axh(1), 'YLim')/100, ...
              'XColor', 'k', 'YColor', 'k', ...
              'XGrid', 'on', 'YGrid', 'on');
  title 'Details of First 5 Seconds'
  print -dpng 'InputData.png'
end%if
